@@ -82,6 +82,7 @@ class Playwright(LibraryComponent):
             os.environ["DEBUG"] = "pw:api"
         logger.info(f"Starting Browser process {playwright_script} using port {port}")
         self.port = port
+        os.environ["PLAYWRIGHT_BROWSERS_PATH"] = "0"
         return Popen(
             ["node", str(playwright_script), port],
             shell=False,
@@ -109,7 +110,7 @@ class Playwright(LibraryComponent):
         )
 
     @contextlib.contextmanager
-    def grpc_channel(self):
+    def grpc_channel(self, original_error=False):
         """Yields a PlayWrightstub on a newly initialized channel
 
         Acts as a context manager, so channel is closed automatically when control returns.
@@ -122,27 +123,16 @@ class Playwright(LibraryComponent):
         channel = grpc.insecure_channel(f"localhost:{self.port}")
         try:
             yield playwright_pb2_grpc.PlaywrightStub(channel)
-        except Exception as e:
-            raise AssertionError(self.get_reason(e))
+        except grpc.RpcError as error:
+            if original_error:
+                raise error
+            raise AssertionError(error.details())
+        except Exception as error:
+            logger.debug(f"Unknown error received: {error}")
+            raise AssertionError(str(error))
         finally:
             channel.close()
 
-    def get_reason(self, err):
-        try:
-            metadata = err.trailing_metadata()
-            for element in metadata:
-                if element.key == "reason":
-                    return element.value
-        except AttributeError:
-            pass
-        try:
-            return err.details()
-        except TypeError:
-            return err.details
-        except AttributeError:
-            pass
-        return str(err)
-
     def close(self):
         logger.debug("Closing all open browsers, contexts and pages in Playwright")
         with self.grpc_channel() as stub:
